==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/ts/Modify_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja_JP">
<context>
    <name>Modify</name>
    <message>
        <location filename="../Modify.js" line="+99"/>
        <source>Modification Tools</source>
        <translation>修正ツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show modification tools</source>
        <translation>修正ツールを表示</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Modify</source>
        <translation>&amp;M 修正</translation>
    </message>
</context>
<context>
    <name>ModifyCorner</name>
    <message>
        <location filename="../ModifyCorner.js" line="+86"/>
        <source>Choose corner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Choose first entity</source>
        <translation>第1エンティティを選択してください</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Choose second entity</source>
        <translation>第2エンティティを選択してください</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Set point</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Transform</name>
    <message>
        <location filename="../Transform.js" line="+47"/>
        <source>This tool requires a selection</source>
        <translation>このツールは選択した状態で使用してください</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/ts/Modify_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Modify</name>
    <message>
        <location filename="../Modify.js" line="+99"/>
        <source>Modification Tools</source>
        <translation>修正ツール</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show modification tools</source>
        <translation>修正ツールを表示</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;Modify</source>
        <translation>&amp;M 修正</translation>
    </message>
</context>
<context>
    <name>ModifyCorner</name>
    <message>
        <location filename="../ModifyCorner.js" line="+86"/>
        <source>Choose corner</source>
        <translation>角を選択</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Choose first entity</source>
        <translation>第1エンティティを選択してください</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Choose second entity</source>
        <translation>第2エンティティを選択してください</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Set point</source>
        <translation>点を設定</translation>
    </message>
</context>
<context>
    <name>Transform</name>
    <message>
        <location filename="../Transform.js" line="+47"/>
        <source>This tool requires a selection</source>
        <translation>このツールは選択した状態で使用してください</translation>
    </message>
</context>
</TS>
